import os

from .algorithms import split_phrase_to_words

s1 = u'ÀÁÂÃÈÉÊÌÍÒÓÔÕÙÚÝàáâãèéêìíòóôõùúýĂăĐđĨĩŨũƠơƯưẠạẢảẤấẦầẨẩẪẫẬậẮắẰằẲẳẴẵẶặẸẹẺẻẼẽẾếỀềỂểỄễỆệỈỉỊịỌọỎỏỐốỒồỔổỖỗỘộỚớỜờỞởỠỡỢợỤụỦủỨứỪừỬửỮữỰựỲỳỴỵỶỷỸỹ'
s0 = u'AAAAEEEIIOOOOUUYaaaaeeeiioooouuyAaDdIiUuOoUuAaAaAaAaAaAaAaAaAaAaAaAaEeEeEeEeEeEeEeEeIiIiOoOoOoOoOoOoOoOoOoOoOoOoUuUuUuUuUuUuUuYyYyYyYy'


def remove_accents(input_str):
    s = ''
    for c in input_str:
        if c in s1:
            s += s0[s1.index(c)]
        else:
            s += c
    return s


class Splitter:

    def __init__(self, languages=['vi']):
        self.languages = languages
        self.dict = {}
        for lang in languages:
            if lang == 'vi' or lang == "teencode":
                self.update_dict(f'dicts/{lang}.txt', rm_accents=True)
            self.update_dict(f'dicts/{lang}.txt')

    def update_dict(self, dict_path, rm_accents=False):
        module_path = os.path.dirname(__file__)
        dict_path = os.path.join(module_path, dict_path)
        word_dict = {}
        f = open(dict_path, 'r')
        lines = f.readlines()
        for l in lines:
            l = l.strip().upper()
            word_dict[l] = True
            if rm_accents:
                word_dict[remove_accents(l)] = True
        self.dict.update(word_dict)

    def split(self, phrase):
        return split_phrase_to_words(phrase, self.dict)



import numpy as np
import os
from typing import Dict, List


MAX_VAL = np.iinfo(np.int32).max


def split_phrase_to_words(phrase, word_dict, max_word_len=10):
    len_phrase = len(phrase)
    dp = np.full(len_phrase + 1, MAX_VAL)
    trade = np.zeros(len_phrase + 1, dtype='int')
    for ind in range(0, len(phrase)):
        for wlen in range(1, max_word_len + 1):
            if (wlen > ind + 1):
                break
            subseq = phrase[ind - wlen + 1: ind + 1]
            if (subseq in word_dict):
                if (ind - wlen == -1):
                    dp[ind] = 1
                    trade[ind] = wlen
                elif (dp[ind] > dp[ind - wlen] + 1):
                    dp[ind] = dp[ind - wlen] + 1
                    trade[ind] = wlen

    if dp[len_phrase - 1] != MAX_VAL:
        ind = len_phrase - 1
        words = []
        while ind >= 0:
            wlen = trade[ind]
            w = phrase[ind - wlen + 1: ind + 1]
            words.append(w)
            ind -= wlen
        words.reverse()
        return words
    else:
        return None


if __name__ == '__main__':

    DICT_PATH = os.path.join(os.getcwd(), 'dicts/vi.txt')

    word_dict = {}
    f = open(DICT_PATH, 'r')
    lines = f.readlines()
    for l in lines:
        l = l.strip().upper()
        word_dict[l] = True
    phrase = 'HÀNI'
    words = split_phrase_to_words(phrase, word_dict=word_dict)
    print(words)



from setuptools import setup, find_packages

setup(
    name="split-vnm-words",
    version="0.0.4",
    packages=find_packages(),
    include_package_data=True,
    package_data={
        "splitwords.dicts": ["dicts/*.txt"],
    },
    install_requires=[
        "numpy",
    ],
)